=================================================
``psyclone.psyir.transformations.nan_test_trans``
=================================================

.. automodule:: psyclone.psyir.transformations.nan_test_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.nan_test_trans


Classes
=======

- :py:class:`NanTestTrans`:
  This transformation inserts a NanTestNode into the PSyIR of a


.. autoclass:: NanTestTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NanTestTrans
      :parts: 1
